## ThePalette
A Color Palette...
## Contact Us
- [Telegram](https://t.me/mpm_ms)
## Example
```python
from thepalette import Color
clr = Color(name="xxx", cmyk=(45, 66, 71, 12))
print(clr.get_hex())
```
## Installing

```bash
pip install thepalette
```